class Crd2pulumi < Formula
  desc "Generate typed CustomResources from a Kubernetes CustomResourceDefinition"
  homepage "https://github.com/pulumi/crd2pulumi"
  url "https://github.com/pulumi/crd2pulumi/archive/refs/tags/v1.5.4.tar.gz"
  sha256 "3dfb4e2e7eb9633c156c78becb866836760ee4c87056d0c47a8288cef85dc14c"
  license "Apache-2.0"
  head "https://github.com/pulumi/crd2pulumi.git", branch: "master"

  depends_on "go" => :build

  def install
    system "go", "build", *std_go_args(ldflags: "-s -w -X github.com/pulumi/crd2pulumi/cmd.Version=#{version}")

    generate_completions_from_executable(bin/"crd2pulumi", "completion")
  end

  test do
    assert_match version.to_s, shell_output("#{bin}/crd2pulumi version")

    test_crd = testpath/"crd.yaml"
    test_crd.write <<~YAML
      apiVersion: apiextensions.k8s.io/v1
      kind: CustomResourceDefinition
      metadata:
        name: widgets.example.com
      spec:
        group: example.com
        names:
          kind: Widget
          plural: widgets
          singular: widget
        scope: Namespaced
        versions:
          - name: v1
            served: true
            storage: true
            schema:
              openAPIV3Schema:
                type: object
                properties:
                  spec:
                    type: object
                    properties:
                      size:
                        type: string
                      color:
                        type: string
    YAML

    # Generate TypeScript code from the CRD
    system bin/"crd2pulumi", "--nodejsPath", testpath/"typescript", test_crd, "--force"

    assert_path_exists testpath/"typescript/example/v1/widget.ts"
    assert_match "this file was generated by crd2pulumi", (testpath/"typescript/provider.ts").read

    # Generate Python code from the CRD
    system bin/"crd2pulumi", "--pythonPath", testpath/"python", "--python", test_crd
    assert_path_exists testpath/"python/pulumi_crds/example/v1/Widget.py"
    assert_match "this file was generated by crd2pulumi", (testpath/"python/pulumi_crds/provider.py").read
  end
end
